ContextInitializedEvent

Struct ContextInitializedEvent 

pub struct ContextInitializedEvent {
    pub config_sources_count: usize,
    pub timestamp: SystemTime,
}
Event fired when the application context is initialized

This event is published after the context has been fully initialized, including all configuration sources and the IoC container.

Fields

config_sources_count: usize

Number of configuration sources loaded

timestamp: SystemTime

Initialization timestamp